def get_key(d: dict, value, idx = 0):
    '''获取字典中第idx个值为value的键'''
    res = []
    for k, v in d.items():
        if v == value:
            res.append(k)
    if len(res) == 0:
        return None
    try:
        return res[idx]
    except IndexError:
        return res[0]

def get_keys(d: dict, value):
    '''获取字典中所有值为value的键'''
    res = []
    for k, v in d.items():
        if v == value:
            res.append(k)
    if len(res) == 0:
        return None
    return res

def count_key(d: dict, value):
    '''获取字典中值为value的键的个数'''
    res = []
    for k, v in d.items():
        if v == value:
            res.append(k)
    return len(res)


from setuptools import setup, Extension, find_packages

with open("README.md", "r", encoding='utf-8') as f:
    long_description = f.read()

with open('requirements.txt', 'r', encoding='utf-8') as f:
    req = f.read().split('\n')

# for i in range(len(req)):
#     req[i] = req[i].split('==')[0]
# print(req)

setup(name='LegendWCF',  # 包名
    version='1.1.0',  # 版本号
    description='对于微信机器人编码体验的提升以及对WCFerry接口的优化',
    long_description=long_description,
    long_description_content_type='text/markdown',
    author='kanwuqing',
    author_email='kanwuqing@163.com',
    url='https://github.com/kanwuqing/LegendWCF',
    install_requires=req,
    license='MPL License',
    packages=find_packages(),
    platforms=["all"],
    classifiers=[
        'Intended Audience :: Developers',
        'Operating System :: OS Independent',
        'Natural Language :: Chinese (Simplified)',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
        'Programming Language :: Python :: 3.12',
        'Topic :: Software Development :: Libraries'
    ],
)



import yaml

def read_yaml(file: str) -> object:
    '''快速读取设置方法
    
    Args:
        file: 读取文件路径
        encoding: 读取时所用的编码格式
    
    Return:
        object类型, 表示读取到的内容, json格式
    '''
    with open(file, 'r', encoding='utf-8') as file:
        data = yaml.safe_load(file)
    return data

def write_yaml(file: str, data) -> None:
    '''快速读取设置方法
    
    Args:
        file: 写入文件路径
        data: 写入内容
        encoding: 写入时所用的编码格式
    '''
    with open(file, 'w', encoding='utf-8') as file:
        yaml.dump(data, file)


import logging.config
from ..data.yaml_ import read_yaml
import os

def SetLegendLogging():
    '''设置logger

    煮啵煮啵, 你的方法还是太吃操作了, 有没有什么简单又强势的写法吗?
    
    ——**有的兄弟,有的**, 这样的写法一共有9种
    '''

    logging_yaml = read_yaml("legendwcf\wcf\logging.yaml")
    handlers = logging_yaml['handlers']
    for key, value in handlers.items():
        if 'filename' in value:
            log_path = (os.path.split(value['filename'])[0])
            if not os.path.exists(log_path):
                os.makedirs(log_path)
    # 配置logging日志：主要从文件中读取handler的配置、formatter（格式化日志样式）、logger记录器的配置
    logging.config.dictConfig(config=logging_yaml)
    ###设置完毕###
    # 获取根记录器：配置信息从yaml文件中获取
    root = logging.getLogger()
    print("rootlogger:", root.handlers)


import orjson

def read_json(file: str, encoding: str='utf-8') -> object:
    '''快速读取设置方法
    
    Args:
        file: 读取文件路径
        encoding: 读取时所用的编码格式
    
    Return:
        object类型, 表示读取到的内容, json格式
    '''
    f = open(file, 'rb')
    res = orjson.loads(f.read())
    f.close()
    return res

def write_json(file: str, data, encoding: str='utf-8') -> None:
    '''快速读取设置方法
    
    Args:
        file: 写入文件路径
        data: 写入内容
        encoding: 写入时所用的编码格式
    '''
    f = open(file, 'wb')
    f.write(orjson.dumps(data))
    f.close()
